@@ -24,6 +24,27 @@ def process_text(text: str, glossary: st.Glossary) -> str:
     return "\n".join(lines_out)
 
 
+def process_epub_file(epub: st.EpubFile, glossary: st.Glossary):
+    """
+    Process an epub file with the glossary.
+
+    :param epub: The epub file to process.
+    :param glossary: The glossary to use.
+    """
+
+    # Process the html files.
+    for html_file in epub.html_files:
+        html_file.text_glossary = process_text(html_file.text, glossary)
+
+    # Process toc.
+    glossary_snippets = [process_text(snippet, glossary) for snippet in epub.toc_file.get_texts(epub.toc_file.text)]
+    epub.toc_file.text_glossary = epub.toc_file.set_texts(epub.toc_file.text, glossary_snippets)
+    epub.toc_file.process_level = st.ProcessLevel.GLOSSARY
+
+    epub.glossary_hash = glossary.hash
+    epub.process_level = st.ProcessLevel.GLOSSARY
+
+
 """
 Internal functions
 """
